@@ -8,17 +8,13 @@
 #' # Look up names like mammalia
 #' name_lookup(query='mammalia', limit = 20)
 #'
-#' # Paging
+#' # Start with an offset
 #' name_lookup(query='mammalia', limit=1)
 #' name_lookup(query='mammalia', limit=1, start=2)
 #'
-#' # large requests, use start parameter
-#' first <- name_lookup(query='mammalia', limit=1000)
-#' second <- name_lookup(query='mammalia', limit=1000, start=1000)
-#' tail(first$data)
-#' head(second$data)
-#' first$meta
-#' second$meta
+#' # large requests (paging is internally implemented).
+#' # hard maximum limit set by GBIF API: 99999
+#' name_lookup(query = "Carnivora", limit = 10000)
 #'
 #' # Get all data and parse it, removing descriptions which can be quite long
 #' out <- name_lookup('Helianthus annuus', rank="species", verbose=TRUE)
@@ -68,8 +64,9 @@
 #' res <- name_lookup(query='canada', hl=TRUE, limit=5)
 #' gbif_names(res)
 #'
-#' # Lookup by datasetKey
-#' name_lookup(datasetKey='3f8a1297-3259-4700-91fc-acc4170b27ce')
+#' # Lookup by datasetKey (set up sufficient high limit, API maximum: 99999)
+#' name_lookup(datasetKey='3f8a1297-3259-4700-91fc-acc4170b27ce',
+#' limit = 50000)
 #'
 #' # Some parameters accept many inputs, treated as OR
 #' name_lookup(rank = c("family", "genus"))
@@ -79,6 +76,8 @@
 #' name_lookup(nameType = c("cultivar", "doubtful"))
 #' name_lookup(datasetKey = c("73605f3a-af85-4ade-bbc5-522bfb90d847",
 #'   "d7c60346-44b6-400d-ba27-8d3fbeffc8a5"))
+#' name_lookup(datasetKey = "289244ee-e1c1-49aa-b2d7-d379391ce265",
+#'   origin = c("SOURCE", "DENORMED_CLASSIFICATION"))
 #'
 #' # Pass on curl options
 #' name_lookup(query='Cnaemidophorus', rank="genus",
@@ -87,7 +86,7 @@
 
 name_lookup <- function(query=NULL, rank=NULL, higherTaxonKey=NULL, status=NULL,
   isExtinct=NULL, habitat=NULL, nameType=NULL, datasetKey=NULL,
-  nomenclaturalStatus=NULL, limit=100, start=NULL, facet=NULL,
+  origin=NULL, nomenclaturalStatus=NULL, limit=100, start=0, facet=NULL,
   facetMincount=NULL, facetMultiselect=NULL, type=NULL, hl=NULL,
   verbose=FALSE, return="all", curlopts = list()) {
 
@@ -106,6 +105,7 @@ name_lookup <- function(query=NULL, rank=NULL, higherTaxonKey=NULL, status=NULL,
   habitat <- as_many_args(habitat)
   nameType <- as_many_args(nameType)
   datasetKey <- as_many_args(datasetKey)
+  origin <- as_many_args(origin)
 
   url <- paste0(gbif_base(), '/species/search')
   args <- rgbif_compact(list(q=query, isExtinct=as_log(isExtinct),
@@ -114,14 +114,52 @@ name_lookup <- function(query=NULL, rank=NULL, higherTaxonKey=NULL, status=NULL,
             facetMultiselect=as_log(facetMultiselect), hl=as_log(hl),
             type=type))
   args <- c(args, facetbyname, rank, higherTaxonKey, status,
-            habitat, nameType, datasetKey)
-  tt <- gbif_GET(url, args, FALSE, curlopts)
+            habitat, nameType, datasetKey, origin)
+
+  # paging implementation
+  if (limit > 1000) {
+    iter <- 0
+    sumreturned <- 0
+    numreturned <- 0
+    outout <- list()
+    while (sumreturned < limit) {
+      iter <- iter + 1
+      tt <- gbif_GET(url, args, FALSE, curlopts)
+      # if no results, assign numreturned var with 0
+      if (identical(tt$results, list())) {
+        numreturned <- 0}
+      else {
+        numreturned <- length(tt$results)}
+      sumreturned <- sumreturned + numreturned
+      # if less results than maximum
+      if ((numreturned > 0) && (numreturned < 1000)) {
+        # update limit for metadata before exiting
+        limit <- numreturned
+        args$limit <- limit
+      }
+      if (sumreturned < limit) {
+        # update args for next query
+        args$offset <- args$offset + numreturned
+        args$limit <- limit - sumreturned
+      }
+      outout[[iter]] <- tt
+    }
+    out <- list()
+    out$results <- do.call(c, lapply(outout, "[[", "results"))
+    out$offset <- args$offset
+    out$limit <- args$limit
+    out$count <- outout[[1]]$count
+    out$endOfRecords <- outout[[iter]]$endOfRecords
+  } else {
+    # retrieve data in a single query
+    out <- gbif_GET(url, args, FALSE, curlopts)
+  }
 
   # metadata
-  meta <- tt[c('offset', 'limit', 'endOfRecords', 'count')]
+  meta <- out[c('offset', 'limit', 'endOfRecords', 'count')]
 
   # facets
-  facets <- tt$facets
+  facets <- out$facets
   if (!length(facets) == 0) {
     facetsdat <- lapply(facets, function(x)
       do.call(rbind, lapply(x$counts, data.frame, stringsAsFactors = FALSE)))
@@ -134,28 +172,28 @@ name_lookup <- function(query=NULL, rank=NULL, higherTaxonKey=NULL, status=NULL,
   if (!verbose) {
     data <- tibble::as_data_frame(data.table::setDF(
       data.table::rbindlist(
-        lapply(tt$results, namelkupcleaner),
+        lapply(out$results, namelkupcleaner),
         use.names = TRUE, fill = TRUE)))
     if (limit > 0) data <- movecols(data, c('key', 'scientificName'))
   } else {
-    data <- tt$results
+    data <- out$results
   }
 
   # hierarchies
-  hierdat <- lapply(tt$results, function(x){
+  hierdat <- lapply(out$results, function(x){
     tmp <- x[ names(x) %in% "higherClassificationMap" ]
     tmpdf <- data.frame(rankkey = names(rgbif_compact(tmp[[1]])),
                         name = unlist(unname(rgbif_compact(tmp[[1]]))),
                         stringsAsFactors = FALSE)
     if (NROW(tmpdf) == 0) NULL else tmpdf
   })
-  names(hierdat) <- vapply(tt$results, "[[", numeric(1), "key")
+  names(hierdat) <- vapply(out$results, "[[", numeric(1), "key")
 
   # vernacular names
-  vernames <- lapply(tt$results, function(x){
+  vernames <- lapply(out$results, function(x){
     rbind_fill(lapply(x$vernacularNames, data.frame))
   })
-  names(vernames) <- vapply(tt$results, "[[", numeric(1), "key")
+  names(vernames) <- vapply(out$results, "[[", numeric(1), "key")
 
   # select output
   return <- match.arg(return, c('meta', 'data', 'facets', 'hierarchy',
