@@ -479,3 +479,25 @@ convmany <- function(x) {
   return(x)
 }
 
+check_vals <- function(x, y){
+  if (is.na(x) || is.null(x)) stop(sprintf("%s can not be NA or NULL", y),
+                                   call. = FALSE)
+  if (length(x) > 1) stop(sprintf("%s has to be length 1", y), call. = FALSE)
+}
+
+check_for_a_pkg <- function(x) {
+  if (!requireNamespace(x, quietly = TRUE)) {
+    stop("Please install ", x, call. = FALSE)
+  } else {
+    invisible(TRUE)
+  }
+}
+
+assert <- function (x, y) {
+  if (!is.null(x)) {
+    if (!inherits(x, y)) {
+      stop(deparse(substitute(x)), " must be of class ",
+          paste0(y, collapse = ", "), call. = FALSE)
+    }
+  }
+}
